@@ -3,6 +3,7 @@ A module implementing a base, primitive-type storage entity.
 """
 
 # built-in
+from copy import copy as _copy
 from io import BytesIO as _BytesIO
 from math import isclose as _isclose
 from struct import pack as _pack
@@ -43,6 +44,19 @@ class Primitive(_Generic[T]):
         ] = {}
         self(value=value)
 
+    @property
+    def size(self) -> int:
+        """Get the size of this primitive."""
+        return self.kind.size
+
+    def __copy__(self) -> "Primitive[T]":
+        """Make a copy of this primitive."""
+        return type(self)(self.kind, value=self.value)
+
+    def copy(self) -> "Primitive[T]":
+        """A simple wrapper for copy."""
+        return _copy(self)
+
     def register_callback(
         self, callback: PrimitiveChangeCallaback[T], once: bool = False
     ) -> int:
